@@ -7,11 +7,9 @@ use std::{
 
 /// Get basic [CpuStats] info the host.
 ///
-/// It only contains row information, to get the delta we need
+/// It only contains raw information, to get the delta you need
 /// to get the diff between N and N-1.
 ///
-/// On linux it will get them from `/proc/stat`.
-///
 /// [CpuStats]: ../cpu/struct.CpuStats.html
 pub fn get_cpustats() -> Result<CpuStats, Error> {
     let file = File::open("/proc/stat")?;
@@ -24,7 +22,7 @@ pub fn get_cpustats() -> Result<CpuStats, Error> {
         // We only need 6 values which can be detected by their 4first bytes
         let first_bytes = &line.as_bytes()[..4];
         match first_bytes {
-            b"intr" | b"ctxt" | b"soft" => {}
+            b"intr" | b"ctxt" | b"soft" | b"proc" => {}
             _ => {
                 line.clear();
                 continue;
@@ -39,6 +37,9 @@ pub fn get_cpustats() -> Result<CpuStats, Error> {
             Some("intr") => &mut cpuctx.interrupts,
             Some("ctxt") => &mut cpuctx.ctx_switches,
             Some("softirq") => &mut cpuctx.soft_interrupts,
+            Some("processes") => &mut cpuctx.processes,
+            Some("procs_running") => &mut cpuctx.procs_running,
+            Some("procs_blocked") => &mut cpuctx.procs_blocked,
             _ => {
                 line.clear();
                 continue;
@@ -65,7 +66,7 @@ pub fn get_cpustats() -> Result<CpuStats, Error> {
         }
 
         // If we've found all our information, we can return.
-        if matched_lines == 3 {
+        if matched_lines == 6 {
             return Ok(cpuctx);
         }
 
