@@ -5,7 +5,7 @@ use std::io::Error;
 
 /// Get the currently logged users.
 ///
-/// Use unsafes call to multiple Unix specific functions [setutxent, getutxent].
+/// Use unsafe calls to multiple Unix specific functions [setutxent, getutxent].
 pub fn get_logged_users() -> Result<Vec<String>, Error> {
     let mut users: Vec<String> = Vec::new();
 
@@ -29,7 +29,5 @@ pub fn get_logged_users() -> Result<Vec<String>, Error> {
 
 /// TODO - Return empty [] for now
 pub fn get_users() -> Result<Vec<String>, Error> {
-    let users: Vec<String> = Vec::new();
-
-    Ok(users)
+    Ok(vec![])
 }
