@@ -1,6 +1,7 @@
 use crate::host;
 use crate::memory::Swap;
 
+use libc::c_ulong;
 use std::{
     fs::File,
     io::{BufRead, BufReader, Error, ErrorKind},
@@ -8,11 +9,8 @@ use std::{
 
 /// Return the [Swap] struct.
 ///
-/// It will get the info from syscall to sysinfo.
-///
-/// Used is simply the total - free.
-///
 /// [Swap]: ../memory/struct.Swap.html
+#[allow(clippy::useless_conversion)]
 pub fn get_swap() -> Result<Swap, Error> {
     // Init sysinfo
     let y = match host::sysinfo() {
@@ -20,10 +18,10 @@ pub fn get_swap() -> Result<Swap, Error> {
         Err(x) => return Err(Error::new(ErrorKind::Other, x)),
     };
 
-    // Compute the values from the sysinfo and divide by 1024 for kb
-    let total_swap = (y.totalswap * y.mem_unit as u64) / 1024;
-    let free_swap = (y.freeswap * y.mem_unit as u64) / 1024;
-    let used_swap = total_swap - free_swap;
+    // Compute the values from the sysinfo and divide by (1024 * 1024) for MB
+    let total_swap: u64 = ((y.totalswap * y.mem_unit as c_ulong) / (1024 * 1024)).into();
+    let free_swap: u64 = ((y.freeswap * y.mem_unit as c_ulong) / (1024 * 1024)).into();
+    let used_swap: u64 = total_swap - free_swap;
     Ok(Swap {
         total: total_swap,
         free: free_swap,
